<?php
/** Minangkabau (Baso Minangkabau)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Bennylin
 * @author Luthfi94
 * @author Naval Scene
 * @author Rahmatdenas
 * @author VoteITP
 */

$fallback = 'id';

$messages = array(
# User preference toggles
'tog-underline'               => 'Garih bawahi link:',
'tog-highlightbroken'         => 'Format link putuih <a href="" class="new">macam iko</a> (pilihan: macam iko<a href="" class="internal">?</a>).',
'tog-justify'                 => 'Ratokan paragraf',
'tog-hideminor'               => 'Suruakkan suntingan ketek di parubahan tabaru',
'tog-hidepatrolled'           => 'Suruakkan suntingan nan lah dijago di parubahan tabaru',
'tog-newpageshidepatrolled'   => 'Suruakkan halaman nan lah dijago dari senarai halaman baru',
'tog-extendwatchlist'         => 'Kambangkan senarai pantauan untuak malihek sado parubahan, indak nan baru se',
'tog-usenewrc'                => 'Gunoan parubahan terkini tingkek lanjut (perlu JavaScript)',
'tog-numberheadings'          => 'Agiah nomor judua sacaro otomatis',
'tog-showtoolbar'             => 'Tampilkan bilah suntiang (paralu JavaScript)',
'tog-editondblclick'          => 'Suntiang laman jo klik ganda (JavaScript)',
'tog-editsection'             => 'Fungsikan penyuntingan subbagian malalui [sunting] pranala',
'tog-editsectiononrightclick' => 'Hiduikan bagian panyuntiangan jo mangklik kanan pado judul bagian (JavaScript)',
'tog-showtoc'                 => 'Caliakkan dafta isi (untuak laman nan mampunyoi labiah dari 3 subbagian)',
'tog-rememberpassword'        => 'Kana log masuak denai di peramban ko (salamo $1 {{PLURAL:$1|hari|hari}})',
'tog-watchcreations'          => 'Tambahkan halaman nan denai buek ka senarai pantauan',
'tog-watchdefault'            => 'Tambahkan halaman yang denai sunting ka senarai pantauan',
'tog-watchmoves'              => 'Tambahkan halaman yang denai pindahkan ka senarai pantauan',
'tog-watchdeletion'           => 'Tambahkan halaman yang denai hapuih ka senarai pantauan',
'tog-minordefault'            => 'Tandoi sadoalah suntiangan sabagai suntiangan ketek sacaro baku',
'tog-previewontop'            => 'Tampilkan pratonton sabalun kotak suntiang',
'tog-previewonfirst'          => 'Caliakkan pratayang pado suntiangan patamo',
'tog-nocache'                 => 'Matikan panyinggahan laman peramban',
'tog-enotifwatchlistpages'    => 'E-mail ambo jiko laman nan denai jago lah barubah',
'tog-enotifusertalkpages'     => 'E-mail ambo jiko laman barundiang denai lah barubah',
'tog-enotifminoredits'        => 'E-mail ambo walau hanyo ado parubahan saketek',
'tog-enotifrevealaddr'        => 'Cogokan alamaik e-mail den pado e-mail notifikasi',
'tog-shownumberswatching'     => 'Tujuakkan jumlah pamantau',
'tog-oldsig'                  => 'Pratayang tando tangan:',
'tog-fancysig'                => 'Palakuan tando tangan sabagai teks wiki (tanpa suatu tautan otomatis)',
'tog-externaleditor'          => 'Gunokan editor eksternal sacaro bawaan (untuak nan ahli sajo, kabutuahan pangaturan khusus pado komputer Sanak [//www.mediawiki.org/wiki/Manual:External_editors Informasi labiah lanjuik.].)',
'tog-externaldiff'            => 'Gunokan diff eksternal sacaro bawaan (untuak nan ahli sajo, kabutuahan pangaturan khusus pado komputer Sanak [//www.mediawiki.org/wiki/Manual:External_editors Informasi labiah lanjuik.].)',
'tog-showjumplinks'           => 'Aktifkan tautan pambantu "langsuang ka"',
'tog-uselivepreview'          => 'Gunokan pratayang langsuang (JavaScript) (eksperimental)',
'tog-forceeditsummary'        => 'Ingekkan awak bilo kotak ringkasan suntiangan masih kosoang',
'tog-watchlisthideown'        => 'Sambunyikan suntiangan awak di dafta pantauan',
'tog-watchlisthidebots'       => 'Sambunyikan suntiangan bot di dafta pantauan',
'tog-watchlisthideminor'      => 'Sambunyikan suntiangan ketek di dafta pantauan',
'tog-watchlisthideliu'        => 'Sambunyikan suntiangan pangguno masuak log di dafta pantauan',
'tog-watchlisthideanons'      => 'Sambunyikan suntiangan pangguno indak di kana di dafta pantauan',
'tog-watchlisthidepatrolled'  => 'Sambunyikan suntiangan tapatroli di dafta pantauan',
'tog-ccmeonemails'            => 'Kiriman awak salinan surel nan awak kiriman ka urang lain',
'tog-diffonly'                => 'Jan tampilan isi laman di bawah pabedoan suntiangan',
'tog-showhiddencats'          => 'Tampilan kategori tasambunyi',
'tog-norollbackdiff'          => 'Jan tampilan pabedoan sasudah malakukan pangambalian',

'underline-always'  => 'Taruih',
'underline-never'   => 'Indak pernah',
'underline-default' => 'Bawaan panjalajah web',

# Font style option in Special:Preferences
'editfont-style'     => 'Gaya tulisan komputer pado kotak panyuntiangan:',
'editfont-default'   => 'Bawaan panjalajah web',
'editfont-monospace' => 'Tulisan Monospace',
'editfont-sansserif' => 'Tulisan Sans-serif',
'editfont-serif'     => 'Tulisan Serif',

# Dates
'sunday'        => 'Akaik',
'monday'        => 'Sinayan',
'tuesday'       => 'Salaso',
'wednesday'     => "Raba'a",
'thursday'      => 'Kamih',
'friday'        => 'Jumek',
'saturday'      => 'Sabtu',
'sun'           => 'Aha',
'mon'           => 'Sin',
'tue'           => 'Sal',
'wed'           => 'Rab',
'thu'           => 'Kam',
'fri'           => 'Jum',
'sat'           => 'Sab',
'january'       => 'Januari',
'february'      => 'Februari',
'march'         => 'Maret',
'april'         => 'April',
'may_long'      => 'Mei',
'june'          => 'Juni',
'july'          => 'Juli',
'august'        => 'Agustus',
'september'     => 'September',
'october'       => 'Oktober',
'november'      => 'November',
'december'      => 'Desember',
'january-gen'   => 'Januari',
'february-gen'  => 'Februari',
'march-gen'     => 'Maret',
'april-gen'     => 'April',
'may-gen'       => 'Mei',
'june-gen'      => 'Juni',
'july-gen'      => 'Juli',
'august-gen'    => 'Agustus',
'september-gen' => 'September',
'october-gen'   => 'Oktober',
'november-gen'  => 'November',
'december-gen'  => 'Desember',
'jan'           => 'Jan',
'feb'           => 'Feb',
'mar'           => 'Mar',
'apr'           => 'Apr',
'may'           => 'Mei',
'jun'           => 'Jun',
'jul'           => 'Jul',
'aug'           => 'Agu',
'sep'           => 'Sep',
'oct'           => 'Okt',
'nov'           => 'Nov',
'dec'           => 'Des',

# Categories related messages
'pagecategories'                 => '{{PLURAL:$1|Kategori|Kategori}}',
'category_header'                => 'Laman dalam kategori "$1"',
'subcategories'                  => 'Subkategori',
'category-media-header'          => 'Laman/Media dalam kategori "$1"',
'category-empty'                 => "''Kini ko, indak ado terdapat laman ataupun media dalam kategori iko.''",
'hidden-categories'              => '{{PLURAL:$1|Kategori tapandam|Kategori tapandam}}',
'hidden-category-category'       => 'Kategori tasambunyi',
'category-subcat-count'          => '{{PLURAL:$2|Kategori ko hanyo punyo subkategori berikut.|Kategori ko punyo {{PLURAL:$1|subkategori|$1 subkategori}}, dari total $2.}}',
'category-subcat-count-limited'  => 'Kategori iko mamiliki {{PLURAL:$1|subkategori|$1 subkategori}} barikuik.',
'category-article-count'         => '{{PLURAL:$2|Kategori ko hanyo punyo laman berikut.|Kategori ko punyo  {{PLURAL:$1|laman|$1 laman}} dari total $2.}}',
'category-article-count-limited' => 'Kategori iko mamiliki {{PLURAL:$1|ciek laman|$1 laman}} barikuik.',
'category-file-count'            => '{{PLURAL:$2|Kategori iko hanyo mamiliki ciek laman barikuik.|Kategori iko mamiliki {{PLURAL:$1|laman|$1 laman}} barikuik, dari total $2.}}',
'category-file-count-limited'    => 'Kategori iko mamiliki {{PLURAL:$1|laman|$1 laman}} barikuik.',
'listingcontinuesabbrev'         => 'cont.',
'index-category'                 => 'Laman nan diindeks',
'noindex-category'               => 'Laman nan indak diindeks',
'broken-file-category'           => 'Laman jo gambar rusak',

'about'         => 'Tentang',
'article'       => 'Artikel',
'newwindow'     => '(buka di jendela baru)',
'cancel'        => 'Batalkan',
'moredotdotdot' => 'Lainnyo...',
'mypage'        => 'Laman ambo',
'mytalk'        => 'Ota denai',
'anontalk'      => 'Ota IP iko',
'navigation'    => 'Navigasi',
'and'           => '&#32;jo',

# Cologne Blue skin
'qbfind'         => 'Pencarian',
'qbbrowse'       => 'Browse',
'qbedit'         => 'Suntiang',
'qbpageoptions'  => 'Laman ko',
'qbpageinfo'     => 'Konteks',
'qbmyoptions'    => 'Laman denai',
'qbspecialpages' => 'Halaman istimewa',
'faq'            => 'FAQ',
'faqpage'        => 'Project:FAQ',

# Vector skin
'vector-action-addsection'       => 'Bagian baru',
'vector-action-delete'           => 'Hapuih',
'vector-action-move'             => 'Pindahkan',
'vector-action-protect'          => 'Lindungi',
'vector-action-undelete'         => 'Pambatalan panghapusan',
'vector-action-unprotect'        => 'Palinduangan',
'vector-simplesearch-preference' => 'Aktifkan pancarian saran nan disampurnokan (hanyo kulik Vector)',
'vector-view-create'             => 'Buek',
'vector-view-edit'               => 'Suntiang',
'vector-view-history'            => 'Caliak riwayat nan lalu',
'vector-view-view'               => 'Baco',
'vector-view-viewsource'         => 'Caliak sumber',
'actions'                        => 'Tindakan',
'namespaces'                     => 'Ruang namo:',
'variants'                       => 'Variasi:',

'errorpagetitle'    => 'Kesalahan',
'returnto'          => 'Baliak ka $1',
'tagline'           => 'Dari {{SITENAME}}',
'help'              => 'Bantuan',
'search'            => 'Cari',
'searchbutton'      => 'Cari',
'go'                => 'Tuju',
'searcharticle'     => 'Tuju',
'history'           => 'Riwayat halaman',
'history_short'     => 'Riwayat',
'updatedmarker'     => 'diubah sajak kunjuangan tarakhir ambo',
'printableversion'  => 'Versi cetak',
'permalink'         => 'Pranala permanen',
'print'             => 'Cetak',
'view'              => 'Tampilkan',
'edit'              => 'Suntiang',
'create'            => 'Buek',
'editthispage'      => 'Suntiang laman ko',
'create-this-page'  => 'Buek laman iko',
'delete'            => 'Hapuih',
'deletethispage'    => 'Hapuih laman iko',
'undelete_short'    => 'Batal hapuih $1 {{PLURAL:$1|suntiangan|suntiangan}}',
'viewdeleted_short' => 'Liek {{PLURAL:$1|ciek suntiangan|$1 suntiangan}} nan dihapuih',
'protect'           => 'Lindungi',
'protect_change'    => 'ubah',
'protectthispage'   => 'Lindungi laman iko',
'unprotect'         => 'Palinduangan',
'unprotectthispage' => 'Bukak palindungan laman iko',
'newpage'           => 'Laman baru',
'talkpage'          => 'Musyawarahkan laman ko',
'talkpagelinktext'  => 'Kecek',
'specialpage'       => 'Laman istimewa',
'personaltools'     => 'Peralatan pribadi',
'postcomment'       => 'Bagian baru',
'articlepage'       => 'Liek isi laman',
'talk'              => 'Pembicaraan',
'views'             => 'Tampilan',
'toolbox'           => 'Kotak pakakeh',
'userpage'          => 'Liek laman pangguno',
'projectpage'       => 'Caliak laman proyek',
'imagepage'         => 'Caliak laman berkas',
'mediawikipage'     => 'Caliak laman pasan',
'templatepage'      => 'Caliak laman templat',
'viewhelppage'      => 'Caliak laman bantuan',
'categorypage'      => 'Caliak laman kategori',
'viewtalkpage'      => 'Caliak laman ota',
'otherlanguages'    => 'Dalam baso lain',
'redirectedfrom'    => '(Dialiahkan dari $1)',
'redirectpagesub'   => 'Laman pengalihan',
'lastmodifiedat'    => 'Laman ko tarakhir diubah pado $1, maso $2.',
'viewcount'         => 'Laman iko alah diakses sabanyak {{PLURAL:$1|ciek kali|$1 kali}}.<br />',
'protectedpage'     => 'Laman nan dilindungi',
'jumpto'            => 'Lompek ka:',
'jumptonavigation'  => 'navigasi',
'jumptosearch'      => 'cari',
'view-pool-error'   => 'Maaf, server sadang sibuak pado kini ko.
Talalu banyak pangguno barusaho mancaliak laman iko.
Tunggu sabanta sabalum Sanak mancubo baliak mangakses laman iko.

$1',
'pool-timeout'      => 'Lewat waktu manunggu kunci',
'pool-queuefull'    => 'Kumpulan antrean panuah',
'pool-errorunknown' => 'Kasalahan nan indak dikatahui',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Tentang {{SITENAME}}',
'aboutpage'            => 'Project:Perihal',
'copyright'            => 'Kandungan tasadio dalam $1',
'copyrightpage'        => '{{ns:project}}:Hak cipta',
'currentevents'        => 'Paristiwa takini',
'currentevents-url'    => 'Project:Paristiwa takini',
'disclaimers'          => 'Penyangkalan',
'disclaimerpage'       => 'Project:Penyangkalan umum',
'edithelp'             => 'Bantuan suntingan',
'edithelppage'         => 'Help:Suntingan',
'helppage'             => 'Help:Kandungan',
'mainpage'             => 'Halaman Utamo',
'mainpage-description' => 'Laman Utamo',
'policy-url'           => 'Project:Kabijakan',
'portal'               => 'Portal komunitas',
'portal-url'           => 'Project:Portal komunitas',
'privacy'              => 'Kebijakan privasi',
'privacypage'          => 'Project:Kebijakan privasi',

'badaccess'        => 'Kesalahan hak akses',
'badaccess-group0' => 'Sanak indak diizinkan untuak malakukan tindakan nan Sanak minta.',
'badaccess-groups' => 'Tindakan nan Sanak minta dibatasi untuak pangguno dalam {{PLURAL:$2|kalompok|ciek dari kelompok}}: $1.',

'versionrequired'     => 'Dibutuahkan MediaWiki versi $1',
'versionrequiredtext' => 'MediaWiki versi $1 dibutuahkan untuak manggunokan laman ijo. Caliak [[Special:Version|laman versi]]',

'ok'                      => 'OK',
'retrievedfrom'           => 'Diperoleh dari "$1"',
'youhavenewmessages'      => 'Awak punyo $1 ($2).',
'newmessageslink'         => 'pasan baru',
'newmessagesdifflink'     => 'parubahan terakhir',
'youhavenewmessagesmulti' => 'Awak ang mandapek pasan baru pado $1',
'editsection'             => 'suntiang',
'editold'                 => 'suntiang',
'viewsourceold'           => 'Caliak sumber',
'editlink'                => 'suntiang',
'viewsourcelink'          => 'Lihek sumber',
'editsectionhint'         => 'Suntiang bagian: $1',
'toc'                     => 'Kandungan',
'showtoc'                 => 'tampilkan',
'hidetoc'                 => 'suruakkan',
'collapsible-collapse'    => 'Ketekan',
'collapsible-expand'      => 'Kambangan',
'thisisdeleted'           => 'Caliak atau kambalian $1?',
'viewdeleted'             => 'Caliak $1?',
'restorelink'             => 'Caliak {{PLURAL:$1|ciek suntiangan|$1 suntiangan}} nan dihapuih',
'feedlinks'               => 'Umpan:',
'feed-invalid'            => 'Tipe pamintaan umpan indak tapek.',
'feed-unavailable'        => 'Umpan sindikasi indak tasadio',
'site-rss-feed'           => '$1 RSS Umpan',
'site-atom-feed'          => '$1 umpan Atom',
'page-rss-feed'           => 'Umpan RSS "$1"',
'page-atom-feed'          => '"$1" umpan Atom',
'red-link-title'          => '$1 (laman alun tasadio)',
'sort-descending'         => 'Urutkan manurun',
'sort-ascending'          => 'Urutkan manaik',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Laman',
'nstab-user'      => 'Laman pangguno',
'nstab-media'     => 'Laman Media',
'nstab-special'   => 'Laman istimewa',
'nstab-project'   => 'Laman proyek',
'nstab-image'     => 'Berkas',
'nstab-mediawiki' => 'Pasan',
'nstab-template'  => 'Templat',
'nstab-help'      => 'Bantuan',
'nstab-category'  => 'Kategori',

# Main script and global functions
'nosuchaction'      => 'Indak ado tindakan tasabuik',
'nosuchactiontext'  => 'Tindakan nan diminta oleh URL tasabuik indak valid. Sanak mungkin salah mangetikkan URL, atau mangikuti suatu pranala nan ndak batua. Hal iko juo mungkin mangindikasikan suatu bug pado parangkaik lunak nan digunokan oleh {{SITENAME}}.',
'nosuchspecialpage' => 'Indak ado laman istimewa tarsabuik',
'nospecialpagetext' => '<strong>Sanak maminta laman istimewa nan indak sah.</strong>

Dafta laman istimewa nan sah dapek dicaliak di [[Special:SpecialPages|{{int:specialpages}}]].',

# General errors
'error'                => 'Kasalahan',
'databaseerror'        => 'Kasalahan basis data',
'dberrortext'          => 'Ado kasalahan sintaks pado pamintaan basis data.
Kasalahan ini mungkin manandokan adonyo sabuah \'\'bug\'\' dalam parangkek lunak.
Pamintaan basis data nan tarakhir adalah:
<blockquote><tt>$1</tt></blockquote>
dari dalam fungsi "<tt>$2</tt>".
Basis data manghasilkan kasalahan "<tt>$3: $4</tt>".',
'dberrortextcl'        => 'Ado kasalahan sintaks pado pamintaan basis data.
Pamintaan basis data nan terakhir adalah:
"$1"
dari dalam fungsi "$2".
Basis data manghasilkan kasalahan "$3: $4".',
'laggedslavemode'      => 'Paringatan: Laman mungkin indak barisi parubahan tabaru.',
'readonly'             => 'Basis data dikunci',
'enterlockreason'      => 'Masuakkan alasan panguncian, tamasuak pakiraan bilo kunci akan dibuka',
'readonlytext'         => 'Basis data sadang dikunci tahadok masuakan baru. Panguruih nan malakukan panguncian mamberikan panjalehan sabagai berikut: <p>$1',
'missing-article'      => 'Basis data indak dapek manamukan teks dari laman yang seharusnyo ado, namo "$1" $2.

Hal ko biasonyo disebabkan dek pranala usang ka riwayat terdahulu dari laman yang lah dihapuih.

Jiko bukan iko penyebabnyo, awak mungkin lah manamukan sabuah bug dalam perangkat lunak ko.
Sila laporkan ka [[Special:ListUsers/sysop|Pengurus]], dengan manandokan alamat URL nan dituju.',
'missingarticle-rev'   => '(revisi#: $1)',
'missingarticle-diff'  => '(Bedo: $1, $2)',
'readonly_lag'         => 'Basis data alah dikunci otomatis salagi basis data sakunder malakukan sinkronisasi jo basis data utamo',
'internalerror'        => 'Kasalahan internal',
'internalerror_info'   => 'Kasalahan internal: $1',
'fileappenderrorread'  => 'Indak dapek mambaco "$1" saat panambahan.',
'fileappenderror'      => 'Indak dapek mamasuakkan "$1" ka "$2".',
'filecopyerror'        => 'Indak dapek manyalin berkas "$1" ke "$2".',
'filerenameerror'      => 'Indak dapek maubah namo berkas "$1" manjadi "$2".',
'filedeleteerror'      => 'Indak dapek mahapuih berkas "$1".',
'directorycreateerror' => 'Indak dapek mambuek direktori "$1".',
'filenotfound'         => 'Indak dapek manamukan berkas "$1".',
'fileexistserror'      => 'Indak dapek manuliah berkas "$1": berkas sudah ado',
'unexpected'           => 'Nilai di lua jangkauan: "$1"="$2".',
'formerror'            => 'Kasalahan: Indak dapek mangiriman formulir',
'badarticleerror'      => 'Tindakan iko indak dapek dilaksanakan di laman iko.',
'cannotdelete'         => 'Laman atau berkas "$1" indak dapek dihapuih.
Mungkin alah dihapuih jo urang lain.',
'badtitle'             => 'Judul indak sah',
'badtitletext'         => 'Permintaan judul laman indak sah, kosong, atau antarbaso atau antarwiki yang salah sambuang. Mungkin juo ado kandungan karakter yang indak buliah digunoan untuak judul.',
'perfcached'           => 'Data barikuik iko diambiak dari singgahan dan mungkin indak data nan baharu:',
'perfcachedts'         => 'Data barikut iko diambiak dari singgahan dan tarakhir dipabaharui pado $1.',
'querypage-no-updates' => 'Pamutakhiran dari laman iko sadang dimatian. Data nan ado di siko saat iko indak akan dimuaik ulang.',
'wrong_wfQuery_params' => 'Parameter salah ka wfQuery()<br />Fungsi: $1<br />Pamintaan: $2',
'viewsource'           => 'Lihek sumber',
'viewsourcefor'        => 'untuak $1',
'actionthrottled'      => 'Tindakan dibatasi',
'actionthrottledtext'  => 'Anda dibatasi untuak malakuan tindakan iko talalu banyak dalam waktu singkek. Sila mancubo laik satalah bara menit.',
'protectedpagetext'    => 'Laman iko alah dikunci untuak manghindari panyuntiangan.',
'viewsourcetext'       => 'Sanak dapek malihek atau manyalin sumber laman iko:',
'protectedinterface'   => 'Laman iko barisi teks antarmuko untuak digunoan oleh parangkaik lunak dan alah dikunci untuak manghindari kasalahan.',
'editinginterface'     => "'''Paringatan:''' Sanak manyuntiang suatu laman nan digunoan untuak manyediakan teks antarmuko untuak parangkaik lunak situs iko. Parubahan teks iko akan mampangaruhi tampilan pado antarmuko pangguno untuak pangguno lain.
Untuak tarjamahan, harap gunokan [//translatewiki.net/wiki/Main_Page?setlang=id translatewiki.net], proyek palokalan MediaWiki.",
'sqlhidden'            => '(Pamintaan SQL disuruakkan)',
'cascadeprotected'     => 'Laman iko alah dilindungi dari panyuntiangan karano disartokan di {{PLURAL:$1|laman|laman-laman}} barikuik nan alah dilindungi jo opsi "runtun":
$2',
'namespaceprotected'   => "Sanak ndak mampunyoi hak akses untuak manyuntiang laman di ruang namo '''$1'''.",
'customcssprotected'   => 'Sanak indak mampunyoi izin untuak maubah laman CSS iko, karano manganduang pangaturan pribadi pangguno lain.',
'customjsprotected'    => 'Sanak ndak mampunyo izin untuak maubah laman JavaScript iko, karano manganduang pangaturan pribadi pangguno lain.',
'ns-specialprotected'  => 'Laman istimewa indak dapek disuntiang.',
'titleprotected'       => "Judul iko alah dilindungi dari pambantuakan oleh [[User:$1|$1]].
Alasan nan diberikan adolah ''$2''.",

# Virus scanner
'virus-badscanner'     => "Kasalahan konfigurasi: pamindai virus indak dikenal: ''$1''",
'virus-scanfailed'     => 'Pamindaian gagal (kode $1)',
'virus-unknownscanner' => 'Antivirus indak dikenal:',

# Login and logout pages
'logouttext'                 => "'''Sanak alah kalua log dari sistem.'''

Sanak dapek taruih manggunoan {{SITENAME}} sacaro anonim, atau Sanak dapek [[Special:UserLogin|masuak log liak]] sabagai pangguno nan samo atau pangguno nan lain.
Parhatian bahawa bara laman mungkin masih taruih manunjukkan bahawa Sanak masih masuak log sampai Sanak mambarasihan singgahan panjelajah web Sanak.",
'welcomecreation'            => '== Salamaik datang, $1! ==

Akun Sanak alah dibuek. Jan lupo maatur konfigurasi [[Special:Preferences|preferensi {{SITENAME}}]] Sanak.',
'yourname'                   => 'Namo pangguno:',
'yourpassword'               => 'Kato sandi:',
'yourpasswordagain'          => 'Ulang baliak kato sandi:',
'remembermypassword'         => 'Kana log masuak denai di komputer ko (salamo $1 {{PLURAL:$1|hari|hari}})',
'securelogin-stick-https'    => 'Tetap tahubuang ka HTTPS sasudah masuk log',
'yourdomainname'             => 'Domain Sanak:',
'externaldberror'            => 'Alah tajadi kasalahan otentikasi basis data eksternal atau Sanak indak diizinan malakuan kamaskini tahadok akun eksternal Sanak.',
'login'                      => 'Masuak log',
'nav-login-createaccount'    => 'Masuak log / buek akun',
'loginprompt'                => "Sanak harus mangaktifan ''cookies'' untuak dapek masuak log ka {{SITENAME}}.",
'userlogin'                  => 'Masuak log / buek akun',
'userloginnocreate'          => 'Masuak log',
'logout'                     => 'Kalua log',
'userlogout'                 => 'Kalua log',
'notloggedin'                => 'Alun masuak log',
'nologin'                    => "Alun mampunyoi akun? '''$1'''.",
'nologinlink'                => 'Cipta akun baru',
'createaccount'              => 'Buek akun baharu',
'gotaccount'                 => "Alah tadaftar sabagai pangguno? '''$1'''.",
'gotaccountlink'             => 'Masuak log',
'userlogin-resetlink'        => 'Lupo detail info masuak Sanak?',
'createaccountmail'          => 'malalui surel',
'createaccountreason'        => 'Alasan:',
'badretype'                  => 'Kato sandi nan Sanak masuakkan salah.',
'userexists'                 => 'Namo pangguna nan Sanak piliah alah dipakai oleh urang lain.
Sila piliah namo nan lain.',
'loginerror'                 => 'Kasalahan masuak log',
'createaccounterror'         => 'Indak dapek mambuek akun: $1',
'nocookiesnew'               => 'Akun pangguno alah dibuek, tapi Sanak alun masuak log.
{{SITENAME}} manggunokan cookies untuak log pangguno.
Sanak mampunyoi cookie dinonaktifkan.
Sila aktifan, sasudah itu masuak log jo namo pangguno dan password baharu Sanak.',
'nocookieslogin'             => '{{SITENAME}} manggunokan cookies untuak log pangguno.
Sanak mampunyoi cookie nan dinonaktifan.
Sila aktifan dan cubo baliak.',
'nocookiesfornew'            => 'Akun pangguno indak dibuek karano kami indak dapek mamastian sumbernyo.
Pastian Sanak alah mangaktifan kuki, lalu muek ulang laman iko dan cubo baliak.',
'noname'                     => 'Namo pangguno nan Sanak masuakkan indak sah.',
'loginsuccesstitle'          => 'Berhasil masuak log',
'loginsuccess'               => "'''Sanak kini lah masuak log di {{SITENAME}} sabagai \"\$1\".'''",
'nosuchuser'                 => 'Indak ado pangguno jo namo "$1".
Namo psngguno msmbedokan kapitalisasi.
Pariso baliak ejaan Sanak, atau [[Special:UserLogin/signup|buek akun baharu]].',
'nosuchusershort'            => 'Indak ado pangguno jo namo "$1".
Sila pariso baliak ejaan Sanak.',
'nouserspecified'            => 'Sanak harus mamasuakkan namo pangguno.',
'login-userblocked'          => 'Pangguno iko diblokir. Indak diizinan/dipabuliahan untuak masuak log.',
'wrongpassword'              => 'Kato sandi nan Sanak masuakkan salah. Sila cubo baliak.',
'wrongpasswordempty'         => 'Sanak ndak mamasuakkan kato sandi. Sila cubo baliak.',
'passwordtooshort'           => 'Kato sandi paliang indak harus tadiri dari {{PLURAL:$1|1 karakter|$1 karakter}}.',
'password-name-match'        => 'Kato sandi Sanak harus babedo dari namo pangguno Sanak.',
'password-login-forbidden'   => 'Panggunoan namo pangguno dan sandi iko alah dilarang.',
'mailmypassword'             => 'Kirim kato sandi baru',
'passwordremindertitle'      => 'Paringatan kato sandi dari {{SITENAME}}',
'passwordremindertext'       => 'Sasaurang (mungkin Sanak, dari alamaik IP $1) maminta kato sandi baharu untuak {{SITENAME}} ($4). Kato sandi samantaro untuak pangguno "$2" alah dibuekan dan diset manjadi "$3". Jikok memang Sanak nan mangajukan pamintaan ini, Sanak paralu masuak log dan mamilih kato sandi baharu kini. Kato sandi samantaro Sanak akan kadaluwarsa dalam wakatu {{PLURAL:$5|sahari|$5 hari}}.

Jikok urang lain nan malakukan pamintaan iko, atau jikok Sanak alah mangingek kato sandi Sanak dan akan tetap manggunokan kato sandi tasabuik, sila abaikan pasan iko dan tatap gunokan kato sandi lamo Sanak.',
'noemail'                    => 'Indak ado alamaik surel nan tacatat untuak pangguno "$1".',
'noemailcreate'              => 'Sanak paralu manyadiokan alamaik surel nan sah',
'passwordsent'               => 'Kato sandi baharu alah dikiriman ka alamaik surel nan didaftakan untuak "$1".
Sila masuak log baliak sasudah manarimo surel tasabuik.',
'blocked-mailpassword'       => 'Alamaik IP Sanak diblokir dari panyuntingan dan karanonyo indak diizinan manggunokan fungsi pangingek kato sandi untuak mancegah panyalahgunoan.',
'eauthentsent'               => 'Sabuah surel untuak konfirmasi alah dikirim ka alamaik surel.
Sanak harus mangikuti instruksi di dalam surel tasabuik untuak malakukan konfirmasi bahawa alamaik tasabuik adolah batua kapunyoan Sanak. {{SITENAME}} indak akan mangaktifan fitur surel jikok langkah iko alun dilakuan.',
'throttled-mailpassword'     => 'Suatu pangingat kato sandi alah dikiriman dalam {{PLURAL:$1|jam|$1 jam}} tarakhir.
Untuak manghindari panyalahgunoan, hanyo ciek kato sandi nan akan dikiriman satiok {{PLURAL:$1|jam|$1 jam}}.',
'mailerror'                  => 'Kasalahan dalam mangirimkan surel: $1',
'acct_creation_throttle_hit' => 'Pangunjung wiki iko jo alamaik IP nan samo jo Sanak alah mambuek {{PLURAL:$1|1 akun|$1 akun}} dalam sahari tarakhir, hinggo jumlah maksimum nan diizinan.
Karanonyo, pangunjuang jo alamaik IP iko indak dapek baliak mambuek akun lain untuak samantaro.',
'emailauthenticated'         => 'Alamaik surel Sanak alah dikonfirmasi pado $3, $2.',
'emailnotauthenticated'      => 'Alamaik surel Sanak alum dikonfirmasi. Sabalun dikonfirmasi Sanak ndak bisa manggunokan fitur surel.',
'noemailprefs'               => 'Sanak harus mamasukan alamaik surel di preferensi Sanak untuak dapek manggunokan fitur-fitur iko.',
'emailconfirmlink'           => 'Konfirmasikan alamaik surel Sanak',
'invalidemailaddress'        => 'Alamaik surel iko indak dapek ditarimo karano formatnyo indak sasuai.
Harap masuakan alamaik surel dalam format nan batua atau kosoangan isian tasabuik.',
'accountcreated'             => 'Akun dibuek',
'accountcreatedtext'         => 'Akun pangguno untuak $1 alah dibuek.',
'createaccount-title'        => 'Pambuekan akun untuak {{SITENAME}}',
'createaccount-text'         => 'Sasaurang alah mambuek sabuah akun untuak alamaik surel Sanak di {{SITENAME}} ($4) jo namo "$2" dan kato sandi "$3". Sanak dianjuakan untuak masuak log dan mangganti kato sandi Sanak kini.

Sanak dapek maabaikan pasan iko jikok akun iko dibuek karano suatu kasalahan.',
'usernamehasherror'          => 'Namo pangguno indak bisa mangandung tando paga',
'login-throttled'            => 'Sanak alah bakali-kali mancoba masuak log.
Sila manunggu sabalun mancubo baliak.',
'login-abort-generic'        => 'Proses masuak Sanak indak berhasil - Dibatalan',
'loginlanguagelabel'         => 'Baso: $1',
'suspicious-userlogout'      => 'Pamintaan Sanak untuak kalua log ditolak karano tampaknyo dikirim oleh panjalajah nan rusak atau proksi panyinggah.',

# E-mail sending
'php-mail-error-unknown' => 'Kasalahan nan indak dikana dalam fungsi mail() PHP',

# Change password dialog
'resetpass'                 => 'Tuka kato sandi',
'resetpass_announce'        => 'Sanak alah masauk log jo kode samantaro nan dikirim malalui surel. Untuak malanjuikkan, Sanak harus mamasuakan kato sandi baru di siko:',
'resetpass_header'          => 'Tuka kato sandi akun',
'oldpassword'               => 'Kato sandi lamo:',
'newpassword'               => 'Kato sandi baharu:',
'retypenew'                 => 'Ketik ulang kato sandi baharu:',
'resetpass_submit'          => 'Atua kato sandi dan masuak log',
'resetpass_success'         => 'Kato sandi Sanak alah berhasil dituka!
Kini mamproses masuak log Sanak...',
'resetpass_forbidden'       => 'Kato sandi indak dapek dituka',
'resetpass-no-info'         => 'Sanak harus masuak log untuak mangakses laman iko sacara langsuang.',
'resetpass-submit-loggedin' => 'Tuka kato sandi',
'resetpass-submit-cancel'   => 'Batalkan',
'resetpass-wrong-oldpass'   => 'Kato sandi indak sah.
Sanak mungkin alah berhasil mangganti kato sandi Sanak atau alah maminto kato sandi samantaro nan baharu.',
'resetpass-temp-password'   => 'Kato sandi samantaro:',

# Special:PasswordReset
'passwordreset'                => 'Setel ulang sandi',
'passwordreset-text'           => 'Langkapi formulir iko untuak manarimo surel pangingek detail akun Sanak.',
'passwordreset-legend'         => 'Tuka baliak kato sandi',
'passwordreset-disabled'       => 'Panukaran baliak kato sandi alah dimatian di wiki iko.',
'passwordreset-pretext'        => '{{PLURAL:$1||Masuakan ciek data di bawah iko}}',
'passwordreset-username'       => 'Namo pangguno:',
'passwordreset-email'          => 'Alamaik surel:',
'passwordreset-emailtitle'     => 'Detail akun di {{SITENAME}}',
'passwordreset-emailtext-ip'   => 'Sasaurang (mungkin Sanak, dari alamaik IP $1) maminta pangingek
detail akun untuak {{SITENAME}} ($4). {{PLURAL:$3|Akun|Akun-akun}} barikuik
takaik jo alamaik surel iko:

$2

{{PLURAL:$3|Sandi samantaro|Sandi samantaro}} barikuik akan kadaluwarsa dalam {{PLURAL:$5|sahari|$5 hari}}.
Sanak harus masuak dan mamiliah sandi baharu kini. Jikok urang lain mambuek
pamintaan iko atau jikok Sanak ingek sandi asali dan indak lai
ingin maubahnyo, Sanak dapek mabaikan pasan iko dan taruih manggunoan sandi lamo.',
'passwordreset-emailtext-user' => 'Sasaurang (mungkin Sanak, dari alamaik IP $1) maminta pangingek detail akun untuak {{SITENAME}} ($4).
{{PLURAL:$3|Akun|Akun-akun}} barikuik takaik jo alamaik surel iko:

$2

{{PLURAL:$3|Sandi samantaro|Sandi samantaro}} barikuik akan kadaluwarsa dalam {{PLURAL:$5|sahari|$5 hari}}.
Sanak harus masuak dan mamiliah sandi baharu kini. Jikok urang lain mambuek
pamintaan iko atau jikok Sanak ingek sandi asali dan indak lai
ingin maubahnyo, Sanak dapek maabaikan pasan iko dan taruih manggunokan sandi lamo.',
'passwordreset-emailelement'   => 'Namo pangguno: $1
Sandi samantaro: $2',
'passwordreset-emailsent'      => 'Surel pangingek alah dikiriman.',

# Edit page toolbar
'bold_sample'     => 'Teks dicetak taba',
'bold_tip'        => 'Teks dicetak taba',
'italic_sample'   => 'Teks dicetak miriang',
'italic_tip'      => 'Teks dicetak miriang',
'link_sample'     => 'Judul pranala',
'link_tip'        => 'Pranala dalam',
'extlink_sample'  => 'http://www.example.com judul pranala',
'extlink_tip'     => 'Pranala lua (ingek awalannyo http://)',
'headline_sample' => 'Teks tajuk',
'headline_tip'    => 'Tingkek 2 tajuk',
'nowiki_sample'   => 'Masuakkan disiko teks yang indak diformat',
'nowiki_tip'      => 'Abaikan pemformatan wiki',
'image_tip'       => 'Cantumkan berkas',
'media_tip'       => 'Pranala berkas',
'sig_tip'         => 'Tandotangan awak jo tando waktu',
'hr_tip'          => 'Garih horizontal',

# Edit pages
'summary'                          => 'Ringkasan:',
'subject'                          => 'Subjek/tajuk:',
'minoredit'                        => 'Iko di suntiang saketek',
'watchthis'                        => 'Pantau laman ko',
'savearticle'                      => 'Simpan halaman',
'preview'                          => 'Pratonton',
'showpreview'                      => 'Lihek pratonton',
'showlivepreview'                  => 'Pratayang langsuang',
'showdiff'                         => 'Lihek parubahan',
'anoneditwarning'                  => "'''Peringatan:''' Awak alun masuak log.
Alamat IP awak akan tacatat pado riwayat suntingan laman ko.",
'anonpreviewwarning'               => "''Sanak alun masuak log. Manyimpan laman akan manyababkan alamaik IP Sanak tacatat pado riwayat suntiangan laman iko.''",
'missingsummary'                   => "'''Paringatan:''' Sanak indak mamasuakan ringkasan panyuntiangan. Jikok Sanak baliak manakan tombol Simpan, suntiangan Sanak akan disimpan tanpa ringkasan panyuntiangan.",
'missingcommenttext'               => 'Sila masuakan komenta di bawah iko.',
'missingcommentheader'             => "'''Paringatan:''' Sanak alun maagihan subjek atau judul untuak komenta Sanak. Jikok Sanak baliak manakan \"{{int:savearticle}}\", suntiangan Sanak akan disimpan tanpa komenta tasabuik.",
'summary-preview'                  => 'Pratonton ringkasan:',
'subject-preview'                  => 'Pratayang sabyek/tajuak:',
'blockedtitle'                     => 'Pangguno diblokir',
'blockedtext'                      => "'''Namo pangguno atau alamaik IP Sanak alah diblokir.'''

Blokir dilakuan oleh $1.
Alasan nan diagiahan adolah ''$2''.

* Diblokir sajak: $8
* Blokir kadaluwarsa pado: $6
* Sasaran pamblokiran: $7

Sanak dapek mahubungi $1 atau [[{{MediaWiki:Grouppage-sysop}}|pangurus lainnyo]] untuak mambicarokan hal iko.

Sanak indak dapek manggunoan fitur 'Kirim surel ka pangguna iko' kacuali Sanak alah mamasuakan alamaik surel nan sah di [[Special:Preferences|preferensi akun]] dan Sanak indak diblokir untuak manggunoannyo.

Alamaik IP Sanak adolah $3, dan ID pamblokiran adolah $5.
Toloang saratokan ciek atau kaduo informasi ini pado satiok patanyaan nan Sanak buek.",
'autoblockedtext'                  => 'Alamaik IP Sanak alah tablokir sacaro otomatis karano digunokan oleh pangguno lain, nan diblokir oleh $1. Pamblokiran dilakuan ateh alasan:

:\'\'$2\'\'

* Diblokir sajak: $8
* Blokir kadaluwarsa pado: $6
* Sasaran pamblokiran: $7

Sanak dapek mahubungi $1 atau [[{{MediaWiki:Grouppage-sysop}}|pengurus lainnya]] untuak mambicarokan hal iko.

Sanak indak dapek manggunoan fitur "kirim surel ka pangguno iko" kacuali Sanak alah mamasuakan alamaik surel nan sah di [[Special:Preferences|preferensi akun]] Sanak dan Sanak indak diblokir untuak manggunoannyo.

Alamat IP Sanak saat ini adolah $3, dan ID pamblokiran adolah #$5.
Toloang saratokan informasi-informasi iko dalam satiok patanyaan Sanak.',
'blockednoreason'                  => 'indak ado alasan nan diagiah.',
'blockedoriginalsource'            => "Isi sumber dari '''$1''' ditunjuakan barikuik iko:",
'blockededitsource'                => "Teks '''suntiangan Sanak''' tahadap '''$1''' ditunjuakan barikuik iko:",
'whitelistedittitle'               => 'Paralu masuak log untuak manyuntiang',
'whitelistedittext'                => 'Sanak harus $1 untuak dapek manyuntiang laman.',
'confirmedittext'                  => 'Sanak harus mangkonfirmasian dahulu alamaik surel Sanak sabalun manyuntiang laman.
Harap masuakan dan validasian alamaik surel Sanak malalui [[Special:Preferences|laman preferensi pangguno]] Sanak.',
'nosuchsectiontitle'               => 'Bagian indak ditamuan',
'nosuchsectiontext'                => 'Sanak mancubo manyuntiang suatu subbagian nan indak ado.
Subbagian iko mungkin dipindahan atau dihapuih katiko Sanak mambukanyo.',
'loginreqtitle'                    => 'Harus masuak log',
'loginreqlink'                     => 'masuak log',
'loginreqpagetext'                 => 'Sanak harus $1 untuak dapek maliek laman lainnyo.',
'accmailtitle'                     => 'Kato sandi alah takirim.',
'accmailtext'                      => "Sabuah kato sandi acak untuak [[User talk:$1|$1]] alah dibuek dan dikiriman ka $2.

Kato sandi untuak akun baharu iko dapek diubah di laman ''[[Special:ChangePassword|pangubahan kato sandi]]'' satalah masuak log.",
'newarticle'                       => '(Baru)',
'newarticletext'                   => "Laman nan awak cari alun ado.
Untuak mambuek laman tu, mulailah dengan menulis dalam kotak di bawah (lihek [[{{MediaWiki:Helppage}}|laman bantuan]] untuak maklumat lanjut).
Jiko awak indak sangajo sampai ka laman ko, klik tombol '''back''' pado penjelajah web awak.",
'anontalkpagetext'                 => "----''Iko adolah laman pambicaraan saurang pangguno anonim nan alun mambuek akun atau indak manggunoannyo.
Jadi, kami tapaso harus mamakai alamat IP nan basangkutan untuak maidentifikasikannyo.
Jikok Sanak adolah saurang pangguno anonim dan marasa mandapekkan komentar-komentar nan indak relevan nan ditujuan langsung kapado Sanak, sila [[Special:UserLogin/signup|mambuek akun]] atau [[Special:UserLogin|masuak log]] untuak mahindari karancuan jo pangguno anonim lainnya di lain wakatu.''",
'noarticletext'                    => 'Kini ko indak ado teks dalam laman ko.
Awak dapek [[Special:Search/{{PAGENAME}}|mancari judul laman ko]] pado laman lain,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} mancari log nan bakaik],
atau [{{fullurl:{{FULLPAGENAME}}|action=edit}} suntiang laman ko]</span>.',
'noarticletext-nopermission'       => 'Kini ko indak ado teks dalam laman iko.
Sanak dapek [[Special:Search/{{PAGENAME}}|malakukan pancaharian untuak judul laman iko]] di laman-laman lain, <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} mancahari log takaik], atau [{{fullurl:{{FULLPAGENAME}}|action=edit}} manyuntiang laman iko]</span>.',
'userpage-userdoesnotexist'        => 'Akun pangguno "<nowiki>$1</nowiki>" indak tadafta.',
'userpage-userdoesnotexist-view'   => 'Pangguno "$1" indak tadafta.',
'blocked-notice-logextract'        => 'Pangguno iko sadang diblokir.
Entri log pamblokiran tabaharu iko disadioan di bawah iko untuak referensi:',
'clearyourcache'                   => "'''Catatan:''' Sasudah manyimpan preferensi, Sanak mungkin paralu mambarasiahan singgahan panjalajah web Sanak untuak mancaliak parubahan. '''Mozilla / Firefox / Safari:''' takan ''Ctrl-R'' (''Cmd-R'' pado Mac);
'''Konqueror:''': takan ''F5'';
'''Opera''' barasiahan singgahan malalui menu ''Tools → Preferences'';
'''Internet Explorer:''' takan ''Ctrl-F5''.",
'usercssyoucanpreview'             => "'''Tips:''' Gunoan tombol \"{{int:showpreview}}\" untuak mauji CSS baharu Sanak sabalun manyimpannyo.",
'userjsyoucanpreview'              => "'''Tips:''' Gunoan tombol \"{{int:showpreview}}\" untuak mauji JS baharu Sanak sabalun manyimpannyo.",
'usercsspreview'                   => "'''Ingeklah bahawa Sanak sadang manampilan pratayang dari CSS Sanak.
Pratayang iko alun disimpan!'''",
'userjspreview'                    => "'''Ingeklah bahawa nan Sanak liek hanyolah pratayang JavaScript Sanak, dan bahawa pratayang tasabuik alun disimpan!'''",
'sitecsspreview'                   => "'''Ingeklah bahawa Sanak hanyo manampilan pratayang dari CSS iko.'''
'''Parubahan alun disimpan!'''",
'sitejspreview'                    => "'''Ingeklah bahawa Sanak hanyo manampilan pratayang dari Kode JavaScript iko.'''
'''Parubahan alun disimpan!'''",
'userinvalidcssjstitle'            => "'''Paringatan:''' Kulik \"\$1\" indak ditamuan. Harap diingek bahawa laman .css dan .js manggunokan huruf kecil, contoh {{ns:user}}:Foo/vector.css dan bukannyo {{ns:user}}:Foo/Vector.css.",
'updated'                          => '(Dipabaharui)',
'note'                             => "'''Catatan:'''",
'previewnote'                      => "'''Iko hanyo tampilan pratonton.'''
Parubahan yang awak lakukan alun disimpan!",
'previewconflict'                  => 'Pratayang iko mancaminan teks pado bagian ateh kotak suntiangan teks sabagaimano akan taliek bilo Sanak manyimpannyo.',
'session_fail_preview'             => "'''Maaf, kami ndak dapek mangolah suntiangan Sanak akibat tahapuihnyo data sesi.
Sila cubo sakali lai.
Jikok masih indak barhasil, cubolah [[Special:UserLogout|kalua log]] dan masuak log baliak.'''",
'session_fail_preview_html'        => "'''Kami indak dapek mamproses suntiangan Sanak karano hilangnyo data sesi.'''

''Karano {{SITENAME}} mangizinan panggunoan HTML mantah, pratayang alah disurukan sabagai pancagahan terhadap serangan JavaScript.''

'''Jikok iko marupokan upayo suntiangan nan sahih, sila cubo lai.
Jikok masih tatap indak bahasil, cubolah [[Special:UserLogout|kalua log]] dan masuak baliak.'''",
'token_suffix_mismatch'            => "'''Suntiangan Sanak ditolak karano aplikasi klien Sanak maubah karakter tando baco pado suntiangan.'''
Suntiangan tasabuik ditolak untuak mancegah kasalahan pado teks laman.
Hal iko kadang tajadi jikok Sanak manggunokan layanan proxy anonim babasis web nan bamasalah.",
'edit_form_incomplete'             => "'''Babarapo bagian dari formulir suntiangan indak mancapai server; pariso baliak apokah suntiangan Sanak tatap utuah dan cubo lai.'''",
'editing'                          => 'Manyuntiang $1',
'editingsection'                   => 'Suntiang $1 (bagian)',
'editingcomment'                   => 'Manyuntiang $1 (bahagian baharu)',
'editconflict'                     => 'Konflik panyuntiangan: $1',
'explainconflict'                  => "Urang lain alah manyuntiang laman iko sajak Sanak mulai manyuntiangnyo.
Bagian ateh teks iko manganduang teks laman saat iko.
Parubahan nan Sanak lakuan ditunjuakan pado bagian bawah teks.
Sanak hanyo paralu magabungan parubahan Sanak jo teks nan alah ado.
'''Hanyo''' teks pado bagian ateh lamanlah nan akan disimpan apobilo Sanak manakan \"{{int:savearticle}}\".",
'yourtext'                         => 'Teks Sanak',
'storedversion'                    => 'Versi tasimpan',
'nonunicodebrowser'                => "'''Paringatan: Panjalajah web Sanak indak mandukung unicode.'''
Alah tadapek sabuah solusi agar Sanak dapek manyuntiang laman jo aman: karakter non-ASCII akan muncua dalam kotak edit sabagai kode heksadesimal.",
'editingold'                       => "'''Paringatan:
Sanak manyuntiang revisi lama suatu laman.
Jikok Sanak manyimpannyo, parubahan-parubahan nan dibuek sajak revisi iko akan hilang.'''",
'yourdiff'                         => 'Pambedoan',
'copyrightwarning'                 => "Untuak diingek bahwa apo nan disumbang kapado {{SITENAME}} dianggap lah dilapeh di bawah $2 (lihek $1 untuak lengkapnyo).
Jiko awak indak ingin apo nan ditulis tu disuntiang dan disebarkan, jan dikirim tulisan tu ka siko.<br />
Awak juo mesti bajanji bahwa itu adolah hasil karya awak surang, atau disalin dari sumber milik basamo atau sumber bebas lainnyo.
'''Jan dikirim karya punyo hak cipta tanpa izin!'''",
'copyrightwarning2'                => "Parhatikan bahawa sadoalah kontribusi terhadap {{SITENAME}} dapek disuntiang, diubah, atau dihapuih oleh panyumbang lainnyo. Jikok Sanak indak ingin tulisan Sanak disuntiang urang lain, jan kiriman ka siko.<br />Sanak jua bajanji bahawa iko adolah hasil karyo Sanak surang, atau disalin dari sumber miliak umum atau sumber bebas nan lain (liek $1 untuak informasi labiah lanjuik). '''JAN KIRIMAN KARYO NAN DILINDUNGI HAK CIPTA TANPA IJIN!'''",
'longpageerror'                    => "'''KASALAHAN: Teks nan Sanak kiriman sagadang $1 kilobita, nan barati labiah gadang dari jumlah maksimum $2 kilobita. Teks indak dapek disimpan.'''",
'readonlywarning'                  => "'''PARINGATAN: Basis data sadang dikunci karano pamaliharaan, sahinggo saat iko Sanak indak dapek manyimpan hasil suntiangan Sanak.
Sanak mungkin paralu manyalin teks suntiangan Sanak iko dan manyimpannyo ka sabuah berkas teks dan mamuekannyo baliak sausai pamaliharaan usai.'''

Pangurus nan mangunci basis data magiahan panjalehan barikuik: $1",
'protectedpagewarning'             => "'''Paringatan: Laman iko sadang dilinduangi sahinggo hanyo pangguno jo hak akses pangurus nan dapek manyuntiangnyo.'''
Entri catatan tarakhir disadioan di bawah untuak referensi:",
'semiprotectedpagewarning'         => "'''Paringatan: Laman iko sadang dilinduangi sahinggo hanyo pangguno tadafta nan bisa manyuntiangnyo.'''
Entri catatan tarakhir disadioan di bawah untuak referensi:",
'cascadeprotectedwarning'          => "'''PARINGATAN:''' Laman iko sadang dilinduangi sahinggo hanyo pangguno jo hak akses pangurus sajo nan dapek manyuntiangnyo karano disaratokan dalam {{PLURAL:$1|laman|laman-laman}} barikuik nan alah dilinduangi jo opsi 'palinduangan runtun':",
'titleprotectedwarning'            => "'''Paringatan: Laman iko alah dilinduangi sahinggo diparaluan [[Special:ListGroupRights|hak khusus]] untuak mambueknyo.'''
Entri catatan tarakhir disadioan di bawah untuak referensi:",
'templatesused'                    => '{{PLURAL:$1|Templat|Templat}} yang digunoan di laman iko:',
'templatesusedpreview'             => '{{PLURAL:$1|Templat|Templat}} yang digunoan dalam pratonton ko:',
'templatesusedsection'             => '{{PLURAL:$1|Templat|Templat}} nan digunoan di bagian iko:',
'template-protected'               => '(dilinduangi)',
'template-semiprotected'           => '(semi-perlindungan)',
'hiddencategories'                 => 'Laman ko marupokan kalompok dari {{PLURAL:$1|1 kategori tapandam|$1 kategori tapandam}}:',
'nocreatetitle'                    => 'Pambuekan laman baharu dibatasi',
'nocreatetext'                     => '{{SITENAME}} alah mambatasi pambuekan laman-laman baharu.
Sanak dapek baliak dan manyuntiang laman nan alah ado, atau sila [[Special:UserLogin|masuak log atau mambuek akun]].',
'nocreate-loggedin'                => 'Sanak ndak mampunyoi hak akses untuak mambuek laman baharu.',
'sectioneditnotsupported-title'    => 'Panyuntiangan bagian indak didukuang',
'sectioneditnotsupported-text'     => 'Panyuntiangan bagian indak didukuang di laman suntiang iko.',
'permissionserrors'                => 'Kasalahan Hak Akses',
'permissionserrorstext'            => 'Sanak ndak mampunyoi hak untuak malakuan hal itu karano {{PLURAL:$1|alasan|alasan-alasan}} barikuik:',
'permissionserrorstext-withaction' => 'Awak indak punyo hak akses untuak $2, karano {{PLURAL:$1|alasan|alasan}} berikut:',
'recreate-moveddeleted-warn'       => "'''Paringatan: Sanak mambuek ulang suatu laman nan alah parnah dihapuih.'''

Harap patimbangan apokah layak untuak malanjutan suntiangan Sanak.
Barikuik adolah log panghapuihan dan pamindahan dari laman iko:",
'moveddeleted-notice'              => 'Laman iko alah dihapuih.
Sabagai referensi, barikuik adolah log panghapusan dan pamindahan laman iko.',
'log-fulllog'                      => 'Liek saluruah log',

# Parser/template warnings
'post-expand-template-inclusion-warning'  => "'''Peringatan:''' Ukuran templat talalu gadang.
Babarapo templat akan diabaikan.",
'post-expand-template-inclusion-category' => 'Laman nan ukurannyo templatnyo malabiahi bateh',
'post-expand-template-argument-warning'   => 'Peringatan: Laman ko barisi satidaknyo ciek uraian templat na baukuran ekspansi nan talalu gadang. 
Uraian-uraian tu alah diabaikan.',
'post-expand-template-argument-category'  => 'Laman nan barisi uraian template nan diabaikan',

# History pages
'viewpagelogs'           => 'Lihek log untuak laman ko',
'currentrev-asof'        => 'Revisi terkini pado $1',
'revisionasof'           => 'Revisi per $1',
'revision-info'          => 'Revisi sajak $1 dek $2',
'previousrevision'       => '← Revisi sabalunnyo',
'nextrevision'           => 'Revisi selanjutnyo →',
'currentrevisionlink'    => 'Revisi terkini',
'cur'                    => 'kini',
'last'                   => 'sabalun',
'histlegend'             => "Membandingkan pilihan: Tandoi dari revisi yang ingin dibandingkan dengan memilih kotak radionyo dan tekan tombol ''Bandingkan revisi pilihan''.<br />
Legend: '''({{int:kini}})''' = perbedaan jo revisi terakhir, '''({{int:dulu}})''' = perbedaan jo revisi sabalunnyo, '''{{int:k}}''' = suntingan ketek, '''{{int:b}}''' = suntingan bot.",
'history-fieldset-title' => 'Telusuri riwayat',
'history-show-deleted'   => 'Hanyo nan dihapuih',
'histfirst'              => 'Nan lamo',
'histlast'               => 'Nan baru',

# Revision feed
'history-feed-item-nocomment' => '$1 pado $2',

# Revision deletion
'rev-delundel'           => 'tampilkan/suruakkan',
'revdelete-logentry'     => 'Maubah tampilan revisi untuak "[[$1]]"',
'revdel-restore'         => 'Ganti tampilan',
'revdel-restore-deleted' => 'revisi nan lah tahapuih',
'revdel-restore-visible' => 'tampilan revisi',
'revdelete-content'      => 'kandungan',
'revdelete-hid'          => 'suruakan $1',
'revdelete-log-message'  => '$1 untuak $2 {{PLURAL:$2|revisi|revisi}}',

# Merge log
'revertmerge' => 'Batal bergabung',

# Diffs
'history-title'           => 'Riwayat revisi dari "$1"',
'difference'              => '(Parbedaan antaro revisi)',
'lineno'                  => 'Barih $1:',
'compareselectedversions' => 'Bandingkan revisi pilihan',
'editundo'                => 'batalkan',
'diff-multi'              => '({{PLURAL:$1|ciek |$1 revisi antaro}} oleh {{PLURAL:$2|ciek|$2 pangguno}} indak ditampilkan)',

# Search results
'searchresults'                    => 'Hasil pencarian',
'searchresults-title'              => 'Hasil pencarian untuak "$1"',
'searchresulttext'                 => 'Untuak informasi lanjut tentang pencarian {{SITENAME}}, lihek [[{{MediaWiki:Helppage}}|{{int:help}}]].',
'searchsubtitle'                   => 'Awak mancari \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|sado laman yang dimulai jo "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|sado laman nan tapauik ka "$1"]])',
'searchsubtitleinvalid'            => "Awak mancari '''$1'''",
'notitlematches'                   => 'Indak ado judul nan pas',
'notextmatches'                    => 'Indak ado judul nan pas',
'prevn'                            => 'sabalunnyo {{PLURAL:$1|$1}}',
'nextn'                            => 'salanjuiknyo {{PLURAL:$1|$1}}',
'prevn-title'                      => 'Sabalunnyo $1 {{PLURAL:$1|hasil|hasil}}',
'nextn-title'                      => 'Barikuiknyo $1 {{PLURAL:$1|hasil|hasil}}',
'shown-title'                      => '↓ Tampilkan $1 {{PLURAL:$1|hasil|hasil}} per lama',
'viewprevnext'                     => 'Tampilkan ($1 {{int:pipe-separator}} $2) ($3)',
'searchmenu-exists'                => "'''Ado laman nan banamo \"[[:\$1]]\" pado wiki ko.'''",
'searchmenu-new'                   => "'''Buek laman \"[[:\$1]]\" di wiki ko!'''",
'searchprofile-articles'           => 'Artikel',
'searchprofile-project'            => '↓ Laman Bantuan dan Proyek',
'searchprofile-images'             => '↓ Multimedia',
'searchprofile-everything'         => '↓ Sadonyo',
'searchprofile-advanced'           => 'Lanjuikan',
'searchprofile-articles-tooltip'   => '↓ Cari di $1',
'searchprofile-project-tooltip'    => 'Cari di $1',
'searchprofile-images-tooltip'     => '↓ Cari untuak berkas',
'searchprofile-everything-tooltip' => '↓ Cari sadoalahnyo (tamasuak laman maota)',
'searchprofile-advanced-tooltip'   => 'Pacaharian di ruang namo tatantu',
'search-result-size'               => '$1 ({{PLURAL:$2|1 kato|$2 kato}})',
'search-result-category-size'      => '{{PLURAL:$1|1 anggota|$1 anggota}} ({{PLURAL:$2|1 subkategori|$2 subkategori}}, {{PLURAL:$3|1 berkas|$3 berkas}})',
'search-redirect'                  => '(pengalihan $1)',
'search-section'                   => '(bagian $1)',
'search-suggest'                   => 'Mungkin maksud awak: $1',
'search-interwiki-caption'         => 'Proyek badunsanak',
'search-interwiki-default'         => 'Hasil $1:',
'search-interwiki-more'            => '(selanjutnyo)',
'search-mwsuggest-enabled'         => 'dengan saran',
'search-mwsuggest-disabled'        => 'indak ado saran',
'searchrelated'                    => 'bakaitan',
'searchall'                        => 'Sadonyo',
'showingresultsheader'             => "{{PLURAL:$5|Hasil '''$1''' dari '''$3'''|Hasil '''$1 - $2''' dari '''$3'''}} untuak '''$4'''",
'nonefound'                        => "'''Catatan''': hanyo babarapo ruangnamo yang dicari sacaro default.
Cubo awali permintaan awak tu jo ''all:'' untuak mancari sado kandungan (tamasuak laman ota, templat, dll), atau gunoan ruangnamo yang diinginkan sabagai awalan.",
'search-nonefound'                 => 'Indak ado hasil nan cocok sasuai jo parmintaan',
'powersearch'                      => 'Pencarian lanjut',
'powersearch-legend'               => 'Pencarian lanjut',
'powersearch-ns'                   => 'Mancari di ruangnamo:',
'powersearch-redir'                => 'Senarai pengalihan',
'powersearch-field'                => 'Mancari',

# Preferences page
'preferences'             => 'Preferensi',
'mypreferences'           => 'Preferensi denai',
'prefs-beta'              => 'Corak Beta',
'prefs-labs'              => 'Corak Uji',
'youremail'               => 'Surek Elektronik:',
'yourrealname'            => 'Namo sabananyo:',
'prefs-help-email'        => 'Alamaik surek elektronik ko hanyo tambahan se, namun paralu untuak maulang kato kunci, jiko awak ang lupo kato kunci.',
'prefs-help-email-others' => 'Awak ang juo dapek mamiliah untuak mangizinkan urang lain manghubungi awak ang jo surek elektronik malalui laman pangguno atau laman ota.
Alamaik surek elektronik awak ang tu indak kan katahuan dek urang lain nan manghubungi awak ang tu.',

# Groups
'group-sysop' => 'Pengurus',

'grouppage-sysop' => '{{ns:project}}:Pengurus',

# User rights log
'rightslog' => 'Log parubahan hak akses',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'suntiang laman ko',

# Recent changes
'nchanges'                        => '$1 {{PLURAL:$1|parubahan|parubahan}}',
'recentchanges'                   => 'Parubahan baru',
'recentchanges-legend'            => 'Pilihan parubahan baru',
'recentchangestext'               => 'Manjajak parubahan terbaru dalam wiki di laman ko.',
'recentchanges-feed-description'  => 'Temukan parubahan baru dalam umpan wiki ko',
'recentchanges-label-newpage'     => 'Suntiang ko mambuek laman baru',
'recentchanges-label-minor'       => 'Iko di suntiang saketek',
'recentchanges-label-bot'         => 'Suntiang ko dibuek dek bot',
'recentchanges-label-unpatrolled' => 'Suntiangan ko alun tajago',
'rcnote'                          => "Berikut ko {{PLURAL:$1|'''1'''|'''$1'''}} parubahan dalam {{PLURAL:$2|hari|'''$2''' hari}} terakhir, sampai $5, pukul $4.",
'rcnotefrom'                      => "Di bawah ko ado parubahan sejak '''$2''' (sampai '''$1''' parubahan).",
'rclistfrom'                      => 'Tampilkan parubahan baru sejak $1',
'rcshowhideminor'                 => '$1 suntingan ketek',
'rcshowhidebots'                  => '$1 bot',
'rcshowhideliu'                   => '$1 pangguno masuak log',
'rcshowhideanons'                 => '$1 pangguno anon',
'rcshowhidepatr'                  => '$1 suntiangan nan tajago',
'rcshowhidemine'                  => '$1 suntingan denai',
'rclinks'                         => 'Tampilkan $1 parubahan baru dalam $2 hari terakhir<br />$3',
'diff'                            => 'beda',
'hist'                            => 'versi',
'hide'                            => 'Suruakkan',
'show'                            => 'Tampilkan',
'minoreditletter'                 => 'k',
'newpageletter'                   => 'B',
'boteditletter'                   => 'b',
'rc-enhanced-expand'              => 'Tampilkan rincian (perlu JavaScript)',
'rc-enhanced-hide'                => 'Suruakkan rincian',

# Recent changes linked
'recentchangeslinked'          => 'Parubahan takaik',
'recentchangeslinked-toolbox'  => '↓ Parubahan takaik',
'recentchangeslinked-title'    => 'Parubahan nan takaik jo "$1"',
'recentchangeslinked-noresult' => 'Indak ado parubahan pado laman nan tapauik salamo periode nan ditantuan',
'recentchangeslinked-summary'  => "Iko adolah senarai parubahan terakhir pado laman yang takaik jo laman tartantu (atau pado kalompok kategori tartantu).
Laman pado [[Special:Watchlist|Senarai pantauan]] ditandoi '''cetak taba'''.",
'recentchangeslinked-page'     => 'Namo laman:',
'recentchangeslinked-to'       => 'Tampilkan parubahan dari laman yang takaik jo laman yang disajikan',

# Upload
'upload'        => 'Unggah berkas',
'uploadlogpage' => 'Log unggah',
'filedesc'      => 'Ringkasan',
'uploadedimage' => 'unggah "[[$1]]"',

'license'        => 'Lisensi:',
'license-header' => 'Lisensi',

# File description page
'file-anchor-link'          => 'Berkas',
'filehist'                  => 'Riwayat berkas',
'filehist-help'             => 'Klik pado tanggal/waktu untuak malihek berkas pado maso tu',
'filehist-revert'           => 'kembalikan',
'filehist-current'          => 'kini ko',
'filehist-datetime'         => 'Tanggal/Waktu',
'filehist-thumb'            => 'Miniatur',
'filehist-thumbtext'        => 'Miniatur untuak versi per $1',
'filehist-user'             => 'Pangguno',
'filehist-dimensions'       => 'Dimensi',
'filehist-comment'          => 'Ulasan',
'imagelinks'                => 'Pranala berkas',
'linkstoimage'              => 'Berikut ko ado {{PLURAL:$1|laman nan takaik|$1 laman nan takaik}} jo berkas ko:',
'nolinkstoimage'            => 'Indak ado laman nan ado batauik ka berkas ko.',
'sharedupload'              => 'Berkas ko barasal dari $1 dan mungkin digunoan oleh berbagai proyek lain.',
'sharedupload-desc-here'    => 'Berkas ko dari $1 dan mungkin digunoan untuak proyek-proyek lain.
Deskripsi dari [$2 laman deskripsi berkas] ditampilkan di bawah.',
'uploadnewversion-linktext' => 'Unggah versi baru dari berkas ko',

# Random page
'randompage' => '↓ Laman sumbarang',

# Statistics
'statistics' => 'Statistik',

'disambiguationspage' => 'Template:disambig',

# Miscellaneous special pages
'nbytes'        => '$1 {{PLURAL:$1|bait|bait}}',
'nmembers'      => '$1 {{PLURAL:$1|anggota|anggota}}',
'prefixindex'   => 'Semua laman jo awalan',
'usercreated'   => 'Dibuek pado $1 waktu $2',
'newpages'      => 'Laman baru',
'move'          => 'Pindahkan',
'movethispage'  => 'Pindahkan laman ko',
'pager-newer-n' => '{{PLURAL:$1|labiah baru 1|labiah baru $1}}',
'pager-older-n' => '{{PLURAL:$1|labiah lamo 1|labiah lamo $1}}',

# Book sources
'booksources'               => 'Sumber buku',
'booksources-search-legend' => 'Cari di sumber buku',
'booksources-go'            => 'Tuju',

# Special:Log
'log' => 'Log',

# Special:AllPages
'allpages'       => 'Semua laman',
'alphaindexline' => '$1 hinggo $2',
'prevpage'       => 'Laman sabalunnyo ($1)',
'allpagesfrom'   => 'Tampilkan laman mulai dari:',
'allpagesto'     => 'Tampilkan laman hinggo:',
'allarticles'    => 'Semua laman',
'allpagessubmit' => 'Tuju',

# Special:Categories
'categories' => 'Kategori',

# Special:LinkSearch
'linksearch'      => 'Pranala lua',
'linksearch-line' => '$1 tapauik dari $2',

# Special:Log/newusers
'newuserlogpage'          => 'Log pangguno baru',
'newuserlog-create-entry' => 'Mendaftar sabagai pangguno',

# Special:ListGroupRights
'listgrouprights-members' => '(senarai anggota)',

# E-mail user
'emailuser' => 'E-mail pangguno',

# Watchlist
'watchlist'         => 'Senarai pantauan denai',
'mywatchlist'       => 'Senarai pantauan den',
'watchlistfor2'     => 'Untuak $1 $2',
'addedwatchtext'    => "Laman \"[[:\$1]]\" lah ditambahkan ka [[Special:Watchlist|senarai pantauan awak]].
Parubahan laman ko tamasuak laman otanyo akan ditampilkan dalam '''cetak taba''' pado [[Special:RecentChanges|senarai parubahan]] agar lebih mudah manjagonyo.",
'removedwatchtext'  => 'Laman "[[:$1]]" lah dihapuih dari [[Special:Watchlist|senarai pantauan awak]].',
'watch'             => 'Pantau',
'watchthispage'     => 'Pantau laman ko',
'unwatch'           => 'Batal pantau',
'watchlist-details' => '{{PLURAL:$1|$1 laman|$1 laman}} dalam senarai pantauan awak, indak tamasuak laman ota.',
'wlshowlast'        => 'Tampilkan $1 jam $2 hari terakhir $3',
'watchlist-options' => 'Pilihan senarai pantauan',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Mamantau...',
'unwatching' => 'indak dipantau le...',

# Delete
'deletepage'            => 'Hapuih laman',
'confirmdeletetext'     => 'Awak akan mahapuih laman atau berkas basamo riwayatnyo.
Pastikan awak mainginkannyo, dan awak lah tahu sagalo akibatnyo dan sasuai jo [[{{MediaWiki:Policy-url}}|kebijakan]] yang balaku.',
'actioncomplete'        => 'Proses selesai',
'actionfailed'          => 'Aksi gagal',
'deletedtext'           => '"$1" lah dihapuih.
Lihek $2 untuak rekam jejak laman yang lah dihapuih.',
'deletedarticle'        => 'dihapuih "[[$1]]"',
'dellogpage'            => 'Log penghapusan',
'deletecomment'         => 'Alasan:',
'deleteotherreason'     => 'Alasan lain/tambahan:',
'deletereasonotherlist' => 'Alasan lain',

# Rollback
'rollbacklink' => 'baliakkan',

# Protect
'protectlogpage'              => 'Log perlindungan',
'protectedarticle'            => 'melindungi "[[$1]]"',
'modifiedarticleprotection'   => 'maubah tingkek perlindungan "[[$1]]"',
'protectcomment'              => 'Alasan:',
'protectexpiry'               => 'Kadaluwarsa:',
'protect_expiry_invalid'      => 'Maso kadaluwarsa indak balaku',
'protect_expiry_old'          => 'Maso kadaluwarsa adolah pado maso lampau',
'protect-text'                => "Awak buliah malihek jo mangganti tingkek perlindungan di siko untuak laman '''$1'''.",
'protect-locked-access'       => "Akun awak indak berhak untuak maubah tingkek perlindungan laman ko.
Berikut ko pengaturan yang balaku untuak laman '''$1''':",
'protect-cascadeon'           => 'Laman ko sedang dilindungi karano tamasuak dalam {{PLURAL:$1|laman|laman}} aktif perlindungan batingkek.
Awak dapek maubah tingkek perlindungannyo, walaupun indak pangaruah pado perlindungan batingkeknyo.',
'protect-default'             => 'Semua pangguno diizinkan',
'protect-fallback'            => 'Memerlukan hak akses "$1"',
'protect-level-autoconfirmed' => 'Blokir pangguno baru dan indak terdaftar',
'protect-level-sysop'         => 'Hanya pengurus',
'protect-summary-cascade'     => 'batingkek',
'protect-expiring'            => 'kadaluwarsa $1 (UTC)',
'protect-cascade'             => 'Lindungi semua laman yang bakaik jo laman ko (perlindungan batingkek)',
'protect-cantedit'            => 'Awak indak dapek maubah tingkek perlindungan laman ko, karano awak indak berhak.',
'restriction-type'            => 'Perlindungan:',
'restriction-level'           => 'Tingkek larangan:',

# Undelete
'undeletelink'     => 'tampilkan/pulihkan',
'undeleteviewlink' => 'liek',
'undeletedarticle' => 'dipulihkan "[[$1]]"',

# Namespace form on various pages
'namespace'      => 'Ruangnamo:',
'invert'         => 'Baliakkan pilihan',
'blanknamespace' => '(Utamo)',

# Contributions
'contributions'       => 'Jariah pangguno',
'contributions-title' => 'Jariah pangguno untuak $1',
'mycontris'           => 'Jariah denai',
'contribsub2'         => 'Untuak $1 ($2)',
'uctop'               => '(atas)',
'month'               => 'Sejak bulan (dan sabalunnyo):',
'year'                => 'Sejak tahun (dan sabalunnyo):',

'sp-contributions-newbies'  => 'Tampilkan jariah pangguno baru',
'sp-contributions-blocklog' => 'log pemblokiran',
'sp-contributions-uploads'  => 'muek',
'sp-contributions-logs'     => 'log',
'sp-contributions-talk'     => 'kecek',
'sp-contributions-search'   => 'Cari jariah',
'sp-contributions-username' => 'Alamat IP atau namo pangguno:',
'sp-contributions-toponly'  => 'Hanyo manampilkan suntiang nan tarakhir',
'sp-contributions-submit'   => 'Cari',

# What links here
'whatlinkshere'            => 'Pranala baliak',
'whatlinkshere-title'      => 'Laman yang bakaik ka "$1"',
'whatlinkshere-page'       => 'Laman:',
'linkshere'                => "Laman-laman ko bakaik ka '''[[:$1]]''':",
'nolinkshere'              => "Indak ado laman nan punyo tautan ka '''[[:$1]]'''.",
'isredirect'               => 'laman pengalihan',
'istemplate'               => 'transklusi',
'isimage'                  => 'tautan berkas',
'whatlinkshere-prev'       => '{{PLURAL:$1|sabalunnyo|sabalunnyo $1}}',
'whatlinkshere-next'       => '{{PLURAL:$1|salanjuiknyo|salanjuiknyo $1}}',
'whatlinkshere-links'      => '← pranala',
'whatlinkshere-hideredirs' => '$1 pengalihan',
'whatlinkshere-hidetrans'  => '$1 transklusi',
'whatlinkshere-hidelinks'  => '$1 pranala',
'whatlinkshere-hideimages' => '$1 pahubuang gambar',
'whatlinkshere-filters'    => 'Penapis',

# Block/unblock
'blockip'                  => 'Blokir pangguno',
'ipboptions'               => '2 jam:2 hours,1 hari:1 day,3 hari:3 days,1 minggu:1 week,2 minggu:2 weeks,1 bulan:1 month,3 bulan:3 months,6 bulan:6 months,1 tahun:1 year,salamonyo:infinite',
'ipblocklist'              => 'Pangguno tablokir',
'blocklink'                => 'blokir',
'unblocklink'              => 'hilangkan blokir',
'change-blocklink'         => 'ubah blokir',
'contribslink'             => 'kontrib',
'blocklogpage'             => 'Log pemblokiran',
'blocklogentry'            => 'memblokir [[$1]] dalam maso berlaku $2 $3',
'unblocklogentry'          => 'mahilangkan blokir $1',
'block-log-flags-nocreate' => 'cipta akun dimatikan',

# Move page
'movepagetext'     => "Formulir di bawah ko digunoan untuak maubah namo suatu laman dan mamindahkan semua data riwayat ka namo baru. Judul lamo tu akan manjadi laman peralihan manuju judul yang baru. Pranala ka judul lamo indak akan baubah. Pastikan diperiksa laman yang [[Special:DoubleRedirects|peralihan ganda]] atau [[Special:BrokenRedirects|peralihan rusak]]. Awak bertanggungjawab untuak memastikan bahwa pranala tu terus manyambuang ka laman yang seharusnyo.

Perhatikan bahwa laman '''indak''' akan dipindah apobilo lah ado laman yang manggunokan judul yang baru, kecuali bilo laman tu kosong atau marupokan laman peralihan dan indak punyo riwayat suntingan. Maksudnyo awak dapek maubah namo laman seperti samulo apobilo ado kesalahan, dan awak indak dapek manimpo laman yang lah ado.

'''Peringatan:''' Iko dapek maakibatkan parubahan yang tak diduga pado laman yang populer. Jadi pastikan awak paham akibat tindakan ko sabalun melanjutkannyo.",
'movepagetalktext' => "Laman ota yang bakaitan akan dipindahkan sacaro otomatis '''kecuali apobilo:'''

*Sebuah laman ota yang indak kosong lah ado pado judul baru, atau
*Awak indak memberi tando pado kotak di bawahnyo

Dalam kasus tu, apobilo diinginkan, awak dapek mamindahkan atau manggabuangkan laman sacaro manual.",
'movearticle'      => 'Pindahkan laman',
'newtitle'         => 'Ka judul baru:',
'move-watch'       => 'Pantau laman ko',
'movepagebtn'      => 'Pindahkan laman',
'pagemovedsub'     => 'Pamindahan berhasil',
'movepage-moved'   => '\'\'\'"$1" lah dipindahkan ka "$2"\'\'\'',
'articleexists'    => 'Laman dengan namo tu lah ado, atau namo yang awak pilih indak tapek. Silakan pilih namo lain',
'talkexists'       => "'''Laman tersebut berhasil dipindahkan, tapi laman otanyo indak dapek dipindahkan karano lah ado laman ota pado judul yang baru. Silakan digabuang laman ota tu sacaro manual.'''",
'movedto'          => 'dipindahkan ka',
'movetalk'         => 'Pindahkan laman ota yang takaik',
'1movedto2'        => 'mamindahkan [[$1]] ka [[$2]]',
'1movedto2_redir'  => 'mamindahkan [[$1]] ka [[$2]] malalui peralihan',
'movelogpage'      => 'Log pemindahan',
'movereason'       => 'Alasan:',
'revertmove'       => 'kembalikan',

# Export
'export' => 'Ekspor laman',

# Namespace 8 related
'allmessagesname'    => 'Namo',
'allmessagesdefault' => 'Teks pasan default',

# Thumbnails
'thumbnail-more'  => 'Pagadang',
'thumbnail_error' => 'Gagal mambuek thumbnail : $1',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Halaman pangguno awak',
'tooltip-pt-mytalk'               => 'Halaman ota awak',
'tooltip-pt-preferences'          => 'Preferensi denai',
'tooltip-pt-watchlist'            => 'Senarai laman nan denai pantau',
'tooltip-pt-mycontris'            => 'Senarai jariah denai',
'tooltip-pt-login'                => 'Awak disarankan untuak masuak log; meskipun, hal tu indak diwajibkan',
'tooltip-pt-logout'               => 'Kalua log',
'tooltip-ca-talk'                 => 'Pembicaraan tentang isi halaman',
'tooltip-ca-edit'                 => 'Awak buliah suntiang laman ko. Gunokan tombol pratonton sabalun manyimpan',
'tooltip-ca-addsection'           => 'Mulai bagian baru',
'tooltip-ca-viewsource'           => 'Laman ko dilinduangi.
Awak hanyo buliah lihek sumber se',
'tooltip-ca-history'              => 'Revisi sabalunnyo laman ko',
'tooltip-ca-protect'              => 'Lindungi laman ko',
'tooltip-ca-delete'               => 'Hapuih laman iko',
'tooltip-ca-move'                 => 'Pindahkan laman ko',
'tooltip-ca-watch'                => 'Tambahkan laman ko ka senarai pantauan awak',
'tooltip-ca-unwatch'              => 'Kaluaan laman ko dari senarai pantauan awak',
'tooltip-search'                  => 'Cari {{SITENAME}}',
'tooltip-search-go'               => 'Cari suatu laman dengan namo yang samo jiko tasadio',
'tooltip-search-fulltext'         => 'Cari laman yang ado teks ko',
'tooltip-p-logo'                  => '↓ Kunjungi laman utamo',
'tooltip-n-mainpage'              => 'Kunjungi Halaman Utamo',
'tooltip-n-mainpage-description'  => 'Kunjungi halaman utamo',
'tooltip-n-portal'                => 'Tentang proyek, apo yang dapek awak lakukan, di mano mancari sasuatu',
'tooltip-n-currentevents'         => 'Temukan informasi latar dari peristiwa kini ko',
'tooltip-n-recentchanges'         => 'Senarai parubahan baru dalam wiki',
'tooltip-n-randompage'            => 'Tampilkan sembarang halaman',
'tooltip-n-help'                  => 'Tampek mancari bantuan',
'tooltip-t-whatlinkshere'         => 'Senarai sado halaman wiki yang punyo pranala ka halaman ko',
'tooltip-t-recentchangeslinked'   => 'Parubahan baru halaman nan bakaik jo laman ko',
'tooltip-feed-rss'                => 'Umpan RSS untuak laman ko',
'tooltip-feed-atom'               => 'Umpan Atom untuak laman ko',
'tooltip-t-contributions'         => 'Lihek senarai jariah pangguno ko',
'tooltip-t-emailuser'             => 'Kirimkan e-mail ka pangguno ko',
'tooltip-t-upload'                => 'Unggah berkas',
'tooltip-t-specialpages'          => 'Senarai semua halaman istimewa',
'tooltip-t-print'                 => 'Versi cetak halaman ko',
'tooltip-t-permalink'             => 'Pranala permanen untuak revisi laman ko',
'tooltip-ca-nstab-main'           => 'Lihek isi laman',
'tooltip-ca-nstab-user'           => 'Caliak laman pangguno',
'tooltip-ca-nstab-special'        => 'Iko adolah laman istimewa, awak indak buliah manyuntiangnyo',
'tooltip-ca-nstab-project'        => 'Lihek laman proyek',
'tooltip-ca-nstab-image'          => 'Caliak laman berkas',
'tooltip-ca-nstab-template'       => 'Lihek templat',
'tooltip-ca-nstab-help'           => 'Caliak laman bantuan',
'tooltip-ca-nstab-category'       => 'Lihek laman kategori',
'tooltip-minoredit'               => 'Tandoi iko sabagai suntingan ketek',
'tooltip-save'                    => 'Simpan yang awak ubah ko',
'tooltip-preview'                 => 'Pratonton parubahan, harap gunokan iko sabalun disimpan',
'tooltip-diff'                    => 'Lihek parubahan yang sudah awak buek tu',
'tooltip-compareselectedversions' => 'Lihek parbedaan antaro duo revisi pilihan laman ko',
'tooltip-watch'                   => 'Tambahkan laman ko ka senarai pantauan awak',
'tooltip-recreate'                => 'Buek baliak laman walaupun sabananyo pernah dihapuih',
'tooltip-upload'                  => 'Mulai mamuek',
'tooltip-rollback'                => '"Baliakkan" baraliah suntiang laman ko pado kontribusi tarakhir dalam sakali klik',
'tooltip-undo'                    => '"Indak jadi" suntiangan ko dibaliakkan dan mambuka kotak suntiang dalam mode pratonton. Alasan dapek ditambah pado kotak ringkasan.',
'tooltip-preferences-save'        => 'Simpan preferensi',
'tooltip-summary'                 => 'Masuakan sabuah ringkasan pendek',

# Metadata
'notacceptable' => 'Layanan wiki indak manyadioan data dalam format yang dapek dibaco dek pelanggan awak.',

# Patrol log
'patrol-log-line' => 'manandoi $1 dari $2 nan tajago $3',
'patrol-log-diff' => 'revisi $1',

# Browsing diffs
'previousdiff' => '← Revisi sabalunnyo',
'nextdiff'     => 'Revisi salanjuiknyo →',

# Media information
'file-info-size' => '$1 × $2 piksel, ukuran berkas: $3, tipe MIME: $4',
'file-nohires'   => '<small>Indak tasadio resolusi yang labiah tinggi.</small>',
'svg-long-desc'  => 'SVG berkas, nominal $1 × $2 piksel, ukuran berkas: $3',
'show-big-image' => 'Resolusi penuh',

# Bad image list
'bad_image_list' => 'Formatnyo sabagai berikut:

Hanyo butir senarai (barih diawali jo tando *) yang dihituang.
Pranala partamo pado barih tu mesti bakaik ka berkas nan buruak.
Pranala-pranala salanjuiknyo pado barih nan samo dianggap sabagai pengecualian, yaitu laman nan dapek manampilkan berkas tu.',

# Metadata
'metadata'          => 'Metadata',
'metadata-help'     => 'Berkas ko mengandung informasi tambahan yang mungkin ditambahkan dek kamera digital atau pemindai yang digunokan untuak mambuek atau mendigitalisasi berkas. Jiko berkas ko lah mangalami modifikasi, rincian yang ado mungkin indak sacaro penuh merefleksikan modifikasi berkas tu.',
'metadata-expand'   => 'Tampilkan rincian tambahan',
'metadata-collapse' => 'Suruakkan rincian tambahan',
'metadata-fields'   => 'Tapak metadata gambar nan disenaraikan dalam pasan ko akan di masuakan pado tampilan laman gambar katiko tabel metadata disuruakkan. 
Nan lainnyo akan tasuruak sacaro default.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# External editor support
'edit-externally'      => 'Suntiang berkas ko dengan aplikasi lua',
'edit-externally-help' => '(Lihek [//www.mediawiki.org/wiki/Manual:External_editors instruksi pengaturan] untuak maklumat lanjutnyo)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'semua',
'namespacesall' => 'semua',
'monthsall'     => 'semua',

# Watchlist editing tools
'watchlisttools-view' => 'Tampilkan parubahan takaik',
'watchlisttools-edit' => 'Tampilkan dan suntiang senarai pantauan',
'watchlisttools-raw'  => 'Suntiang senarai pantauan mentah',

# Core parser functions
'duplicate-defaultsort' => '\'\'\'Peringatan:\'\'\' Kunci panguruitan default "$2" sabalunnyo maabaikan kunci panguruitan default "$1".',

# Special:FileDuplicateSearch
'fileduplicatesearch-result-n' => 'Berkas "$1" punyo {{PLURAL:$2|1 duplikat identik|$2 duplikat identik}}.',

# Special:SpecialPages
'specialpages' => 'Laman istimewa',

# External image whitelist
'external_image_whitelist' => '#Bia se barih ko apo adonyo<pre>
#Latakan fragmen tando regular (hanyo bagian antaro //) di bawah ko
#Iko akan dicocokan jo URL gambar lua (tahubuang langsuang)
#Yang mano cocok akan ditampilkan sabagai gambar, sisonyo hanyo sabagai tautan sajo
#Barih dimulai jo # dipalakuan sabagai komentar
#Iko indak manbedaan huruf gadang atau ketek

#Latakan sado fragmen regex di bawah barih ko. Bia se barih apo adonyo</pre>',

# Special:Tags
'tag-filter' => '[[Special:Tags|Tag]] bateh:',

);
